import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 单位机构服务对象基类
 *
 * @export
 * @class SysOrganizationServiceBase
 * @extends {EntityServie}
 */
export default class SysOrganizationServiceBase extends EntityService {

    /**
     * Creates an instance of  SysOrganizationServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  SysOrganizationServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof SysOrganizationServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='sysorganization';
        this.APPDEKEY = 'orgid';
        this.APPDENAME = 'sysorganizations';
        this.APPDETEXT = 'orgname';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysOrganizationServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().get(`/sysorganizations/${context.sysorganization}/select`,isloading);
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysOrganizationServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let sysdepartmentsData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_sysdepartments'),'undefined')){
            sysdepartmentsData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_sysdepartments') as any);
            if(sysdepartmentsData && sysdepartmentsData.length && sysdepartmentsData.length > 0){
                sysdepartmentsData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.deptid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.sysdepartments = sysdepartmentsData;
        let sysemployeesData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_sysemployees'),'undefined')){
            sysemployeesData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_sysemployees') as any);
            if(sysemployeesData && sysemployeesData.length && sysemployeesData.length > 0){
                sysemployeesData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.userid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.sysemployees = sysemployeesData;
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/sysorganizations`,data,isloading);
        this.tempStorage.setItem(tempContext.srfsessionkey+'_sysdepartments',JSON.stringify(res.data.sysdepartments));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_sysemployees',JSON.stringify(res.data.sysemployees));
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysOrganizationServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let sysdepartmentsData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_sysdepartments'),'undefined')){
            sysdepartmentsData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_sysdepartments') as any);
            if(sysdepartmentsData && sysdepartmentsData.length && sysdepartmentsData.length > 0){
                sysdepartmentsData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.deptid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.sysdepartments = sysdepartmentsData;
        let sysemployeesData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_sysemployees'),'undefined')){
            sysemployeesData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_sysemployees') as any);
            if(sysemployeesData && sysemployeesData.length && sysemployeesData.length > 0){
                sysemployeesData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.userid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.sysemployees = sysemployeesData;
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/sysorganizations/${context.sysorganization}`,data,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_sysdepartments',JSON.stringify(res.data.sysdepartments));
            this.tempStorage.setItem(context.srfsessionkey+'_sysemployees',JSON.stringify(res.data.sysemployees));
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysOrganizationServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().delete(`/sysorganizations/${context.sysorganization}`,isloading);

    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysOrganizationServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = await Http.getInstance().get(`/sysorganizations/${context.sysorganization}`,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_sysdepartments',JSON.stringify(res.data.sysdepartments));
            this.tempStorage.setItem(context.srfsessionkey+'_sysemployees',JSON.stringify(res.data.sysemployees));
            return res;

    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysOrganizationServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any = await  Http.getInstance().get(`/sysorganizations/getdraft`,isloading);
        res.data.sysorganization = data.sysorganization;
            this.tempStorage.setItem(context.srfsessionkey+'_sysdepartments',JSON.stringify(res.data.sysdepartments));
            this.tempStorage.setItem(context.srfsessionkey+'_sysemployees',JSON.stringify(res.data.sysemployees));
        return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysOrganizationServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().post(`/sysorganizations/${context.sysorganization}/checkkey`,data,isloading);
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysOrganizationServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let sysdepartmentsData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_sysdepartments'),'undefined')){
            sysdepartmentsData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_sysdepartments') as any);
            if(sysdepartmentsData && sysdepartmentsData.length && sysdepartmentsData.length > 0){
                sysdepartmentsData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.deptid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.sysdepartments = sysdepartmentsData;
        let sysemployeesData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_sysemployees'),'undefined')){
            sysemployeesData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_sysemployees') as any);
            if(sysemployeesData && sysemployeesData.length && sysemployeesData.length > 0){
                sysemployeesData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.userid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.sysemployees = sysemployeesData;
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/sysorganizations/${context.sysorganization}/save`,data,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_sysdepartments',JSON.stringify(res.data.sysdepartments));
            this.tempStorage.setItem(context.srfsessionkey+'_sysemployees',JSON.stringify(res.data.sysemployees));
            return res;
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysOrganizationServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/sysorganizations/fetchdefault`,tempData,isloading);
    }
}